;; /usr/share/emacs/site-lisp/suse-start-Mule-UCS.el

(add-to-list 'load-path "/usr/share/emacs/site-lisp/Mule-UCS")

(require 'un-define)
(require 'unicode)

;; Tue Sep 17 15:42:48 2002  Mike Fabian  <mfabian@suse.de>
;; 
;; the following code creates some additional fontsets using mainly
;; Unicode fonts.
;;
;; If you want to use one of these font sets as your default fontset,
;; add a line like the following to your ~/.emacs:
;; 
;; (setq default-frame-alist `((font . "fontset-16_efont_unicode")))

(defun mule-ucs-create-fontset-unicode (name narrow-font wide-font)
  (interactive)
  (let ((narrow-charsets (list
			  'latin-iso8859-1 
			  'latin-iso8859-2 
			  'latin-iso8859-3 
			  'latin-iso8859-4 
			  'cyrillic-iso8859-5 
			  'greek-iso8859-7 
			  'hebrew-iso8859-8 
			  'latin-iso8859-9 
			  'latin-iso8859-15 
			  'katakana-jisx0201))
	(wide-charsets (list 
			'japanese-jisx0208 
			'japanese-jisx0212 
			'korean-ksc5601 
			'chinese-big5-1 
			'chinese-gb2312 
			'chinese-cns11643-1 
			'chinese-cns11643-2 
			'chinese-cns11643-3 
			'chinese-cns11643-4 
			'chinese-cns11643-5 
			'chinese-cns11643-6 
			'chinese-cns11643-7))
	(new-fontset     (create-fontset-from-ascii-font
			  narrow-font wide-font name))
	)
    (mapcar (lambda (x) (set-fontset-font (concat "fontset-" name) x narrow-font))
	    narrow-charsets)
    (mapcar (lambda (x) (set-fontset-font (concat "fontset-" name) x wide-font))
	    wide-charsets)
    new-fontset))

(defun mule-ucs-create-fontsets-unicode ()
  (let ((fontsets
	 '(("12_efont_unicode"
	    "-efont-fixed-medium-r-normal-*-12-120-75-75-c-60-iso10646-1"
	    "-efont-fixed-medium-r-normal-*-12-120-75-75-c-120-iso10646-1")
	   ("13_misc_unicode"
	    "-misc-fixed-medium-r-semicondensed-*-13-120-75-75-c-60-iso10646-1"
	    "-misc-fixed-medium-r-normal-*-13-120-75-75-c-120-iso10646-1")
	   ("14_efont_unicode"
	    "-efont-fixed-medium-r-normal-*-14-140-75-75-c-70-iso10646-1"
	    "-efont-fixed-medium-r-normal-*-14-140-75-75-c-140-iso10646-1")
	   ("16_efont_unicode"
	    "-efont-fixed-medium-r-normal--16-160-75-75-c-80-iso10646-1"
	    "-efont-fixed-medium-r-normal--16-160-75-75-c-160-iso10646-1")
	   ("16_gnu_unicode"
	    "-gnu-unifont-medium-r-normal--16-160-75-75-c-80-iso10646-1"
	    "-gnu-unifont-medium-r-normal--16-160-75-75-c-80-iso10646-1")
	   ("18_misc_unicode"
	    "-misc-fixed-medium-r-normal-*-18-120-100-100-c-90-iso10646-1"
	    "-misc-fixed-medium-r-normal-*-18-120-100-100-c-180-iso10646-1")
	   ("24_efont_unicode"
	    "-efont-fixed-medium-r-normal-*-24-240-75-75-c-120-iso10646-1"
	    "-efont-fixed-medium-r-normal-*-24-240-75-75-c-240-iso10646-1"))))
    (mapcar (lambda (x)
	      (let ((name (nth 0 x))
		    (narrow-font (nth 1 x))
		    (wide-font (nth 2 x)))
		(and (x-list-fonts narrow-font)
		     (x-list-fonts wide-font)
		     (mule-ucs-create-fontset-unicode name narrow-font wide-font))))
	    fontsets)))

(when (eq window-system 'x)
  (mule-ucs-create-fontsets-unicode))

;;
;; Mule UCS charset order (see also bugzilla #155717):
;;

(let ((case-fold-search nil)
      (ctype (cond ((getenv "LC_ALL")
		    (getenv "LC_ALL"))
		   ((getenv "LC_CTYPE")
		    (getenv "LC_CTYPE"))
		   ((getenv "LANG")
		    (getenv "LANG"))
		   (t
		    "POSIX"))))
  (cond ((string-match "zh_CN" ctype)
	 (un-define-change-charset-order 
	  '(ascii
	    latin-iso8859-1
	    latin-iso8859-2
	    latin-iso8859-3
	    latin-iso8859-4
	    cyrillic-iso8859-5
	    greek-iso8859-7
	    hebrew-iso8859-8
	    latin-iso8859-9
	    latin-iso8859-14
	    latin-iso8859-15
	    ipa
	    chinese-gb2312
	    chinese-cns11643-1
	    chinese-cns11643-2
	    chinese-cns11643-3
	    chinese-cns11643-4
	    chinese-cns11643-5
	    chinese-cns11643-6
	    chinese-cns11643-7
	    chinese-big5-1
	    chinese-big5-2
	    chinese-sisheng
	    korean-ksc5601
	    japanese-jisx0208
	    japanese-jisx0212
	    latin-jisx0201
	    katakana-jisx0201
	    thai-tis620
	    ethiopic
	    indian-is13194
	    lao
	    vietnamese-viscii-lower
	    vietnamese-viscii-upper
	    mule-unicode-0100-24ff
	    mule-unicode-2500-33ff
	    mule-unicode-e000-ffff
	    mule-ucs-unicode-multichar)))
	((string-match "zh_SG" ctype)
	 (un-define-change-charset-order 
	  '(ascii
	    latin-iso8859-1
	    latin-iso8859-2
	    latin-iso8859-3
	    latin-iso8859-4
	    cyrillic-iso8859-5
	    greek-iso8859-7
	    hebrew-iso8859-8
	    latin-iso8859-9
	    latin-iso8859-14
	    latin-iso8859-15
	    ipa
	    chinese-gb2312
	    chinese-cns11643-1
	    chinese-cns11643-2
	    chinese-cns11643-3
	    chinese-cns11643-4
	    chinese-cns11643-5
	    chinese-cns11643-6
	    chinese-cns11643-7
	    chinese-big5-1
	    chinese-big5-2
	    chinese-sisheng
	    korean-ksc5601
	    japanese-jisx0208
	    japanese-jisx0212
	    latin-jisx0201
	    katakana-jisx0201
	    thai-tis620
	    ethiopic
	    indian-is13194
	    lao
	    vietnamese-viscii-lower
	    vietnamese-viscii-upper
	    mule-unicode-0100-24ff
	    mule-unicode-2500-33ff
	    mule-unicode-e000-ffff
	    mule-ucs-unicode-multichar)))
	((string-match "zh_TW" ctype)
	 (un-define-change-charset-order 
	  '(ascii
	    latin-iso8859-1
	    latin-iso8859-2
	    latin-iso8859-3
	    latin-iso8859-4
	    cyrillic-iso8859-5
	    greek-iso8859-7
	    hebrew-iso8859-8
	    latin-iso8859-9
	    latin-iso8859-14
	    latin-iso8859-15
	    ipa
	    chinese-cns11643-1
	    chinese-cns11643-2
	    chinese-cns11643-3
	    chinese-cns11643-4
	    chinese-cns11643-5
	    chinese-cns11643-6
	    chinese-cns11643-7
	    chinese-big5-1
	    chinese-big5-2
	    chinese-gb2312
	    chinese-sisheng
	    korean-ksc5601
	    japanese-jisx0208
	    japanese-jisx0212
	    latin-jisx0201
	    katakana-jisx0201
	    thai-tis620
	    ethiopic
	    indian-is13194
	    lao
	    vietnamese-viscii-lower
	    vietnamese-viscii-upper
	    mule-unicode-0100-24ff
	    mule-unicode-2500-33ff
	    mule-unicode-e000-ffff
	    mule-ucs-unicode-multichar)))
	((string-match "zh_HK" ctype)
	 (un-define-change-charset-order 
	  '(ascii
	    latin-iso8859-1
	    latin-iso8859-2
	    latin-iso8859-3
	    latin-iso8859-4
	    cyrillic-iso8859-5
	    greek-iso8859-7
	    hebrew-iso8859-8
	    latin-iso8859-9
	    latin-iso8859-14
	    latin-iso8859-15
	    ipa
	    chinese-cns11643-1
	    chinese-cns11643-2
	    chinese-cns11643-3
	    chinese-cns11643-4
	    chinese-cns11643-5
	    chinese-cns11643-6
	    chinese-cns11643-7
	    chinese-big5-1
	    chinese-big5-2
	    chinese-gb2312
	    chinese-sisheng
	    korean-ksc5601
	    japanese-jisx0208
	    japanese-jisx0212
	    latin-jisx0201
	    katakana-jisx0201
	    thai-tis620
	    ethiopic
	    indian-is13194
	    lao
	    vietnamese-viscii-lower
	    vietnamese-viscii-upper
	    mule-unicode-0100-24ff
	    mule-unicode-2500-33ff
	    mule-unicode-e000-ffff
	    mule-ucs-unicode-multichar)))
	((string-match "ko" ctype)
	 (un-define-change-charset-order 
	  '(ascii
	    latin-iso8859-1
	    latin-iso8859-2
	    latin-iso8859-3
	    latin-iso8859-4
	    cyrillic-iso8859-5
	    greek-iso8859-7
	    hebrew-iso8859-8
	    latin-iso8859-9
	    latin-iso8859-14
	    latin-iso8859-15
	    ipa
	    korean-ksc5601
	    japanese-jisx0208
	    japanese-jisx0212
	    chinese-cns11643-1
	    chinese-cns11643-2
	    chinese-cns11643-3
	    chinese-cns11643-4
	    chinese-cns11643-5
	    chinese-cns11643-6
	    chinese-cns11643-7
	    chinese-big5-1
	    chinese-big5-2
	    chinese-gb2312
	    chinese-sisheng
	    latin-jisx0201
	    katakana-jisx0201
	    thai-tis620
	    ethiopic
	    indian-is13194
	    lao
	    vietnamese-viscii-lower
	    vietnamese-viscii-upper
	    mule-unicode-0100-24ff
	    mule-unicode-2500-33ff
	    mule-unicode-e000-ffff
	    mule-ucs-unicode-multichar)))))

;; /usr/share/emacs/site-lisp/suse-start-Mule-UCS.el ends here
